@@ -3,12 +3,15 @@
 
 from __future__ import print_function
 
+import os
+import boto3
 import contextlib
 import io
 import json
 import logging
 import subprocess
 import sys
+import base64
 from time import sleep
 from uuid import uuid4
 
@@ -25,6 +28,7 @@ from IPython.core.magic import (
     line_magic,
 )
 from IPython.core.magic_arguments import magic_arguments, argument, parse_argstring
+from botocore.exceptions import ClientError
 
 # The class MUST call this class decorator at creation time
 # https://ipython.readthedocs.io/en/stable/config/custommagics.html
@@ -248,39 +252,45 @@ class IpythonWidgetBasedAuthProvider:
     def get_credentials_and_connect_to_cluster(
         self, emr_client, args, emr_cluster, kernel_name
     ):
-        username = widgets.Text(
-            value="", placeholder="", description="Username:", disabled=False
-        )
-        password = widgets.Password(
-            value="",
-            placeholder="Enter password",
-            description="Password:",
-            disabled=False,
-        )
-        display(username, password)
-        button = widgets.Button(
-            description="Connect",
-            disabled=False,
-            button_style="",
-            tooltip="Connect to EMR",
-            icon="",
-        )
-        output = widgets.Output()
-        display(button, output)
+        # If the Notebook is run in headless mode and a --secret parameter is not provided, we raise an exception to notify the same.
+        if "SM_JOB_DEF_VERSION" in os.environ:
+            raise ValueError(
+                "A --secret parameter needs to be added to run the Notebook in Headless mode"
+            )
+        else:
+            username = widgets.Text(
+                value="", placeholder="", description="Username:", disabled=False
+            )
+            password = widgets.Password(
+                value="",
+                placeholder="Enter password",
+                description="Password:",
+                disabled=False,
+            )
+            display(username, password)
+            button = widgets.Button(
+                description="Connect",
+                disabled=False,
+                button_style="",
+                tooltip="Connect to EMR",
+                icon="",
+            )
+            output = widgets.Output()
+            display(button, output)
 
-        # Do not remove the unused param otherwise the button will become unresponsive
-        def _on_button_clicked(b):
-            with output:
-                _connect_to_cluster(
-                    emr_client=emr_client,
-                    args=args,
-                    emr_cluster=emr_cluster,
-                    kernel_name=kernel_name,
-                    username=username.value,
-                    password=password.value,
-                )
+            # Do not remove the unused param otherwise the button will become unresponsive
+            def _on_button_clicked(b):
+                with output:
+                    _connect_to_cluster(
+                        emr_client=emr_client,
+                        args=args,
+                        emr_cluster=emr_cluster,
+                        kernel_name=kernel_name,
+                        username=username.value,
+                        password=password.value,
+                    )
 
-        button.on_click(_on_button_clicked)
+            button.on_click(_on_button_clicked)
 
 
 def _connect_to_cluster(emr_client, args, emr_cluster, kernel_name, username, password):
@@ -564,7 +574,9 @@ def _initiate_emr_connect(args, cluster, emr_client, boto_session, kernel_name):
             kernel_name=kernel_name,
         )
     # For HTTP-Basic/LDAP/Kerberos authentication
-    elif cluster.is_krb_cluster or args.auth_type == AUTH_TYPE_BASIC_ACCESS:
+    elif (
+        cluster.is_krb_cluster or args.auth_type == AUTH_TYPE_BASIC_ACCESS
+    ) and args.secret is None:
         auth_provider = IpythonWidgetBasedAuthProvider()
         auth_provider.get_credentials_and_connect_to_cluster(
             emr_client=emr_client,
@@ -572,6 +584,18 @@ def _initiate_emr_connect(args, cluster, emr_client, boto_session, kernel_name):
             emr_cluster=cluster,
             kernel_name=kernel_name,
         )
+    elif (
+        cluster.is_krb_cluster or args.auth_type == AUTH_TYPE_BASIC_ACCESS
+    ) and args.secret is not None:
+        response = _get_secret(args.secret)
+        _connect_to_cluster(
+            emr_client=emr_client,
+            args=args,
+            emr_cluster=cluster,
+            username=response["username"],
+            password=response["password"],
+            kernel_name=kernel_name,
+        )
     # For no authentication
     else:
         _initiate_connect_based_on_kernel(
@@ -704,6 +728,12 @@ class SagemakerAnalytics(Magics):
         help="The IAM role passed to EMR to set up EMR job security context. This argument is optional and "
         "used when IAM Passthrough feature is enabled for EMR.",
     )
+    @argument(
+        "--secret",
+        type=str,
+        default=None,
+        help="The AWS Secrets Manager SecretID.",
+    )
     def sm_analytics(self, line):
         usage = "Please look at usage of %sm_analytics by executing `%sm_analytics?`."
         user_input = line
@@ -848,3 +878,26 @@ def _build_response(cluster_id, error_message, success, service, operation):
         "service": service,
         "operation": operation,
     }
+
+
+def _get_secret(secret_id):
+
+    # Create a Secrets Manager client
+    session = get_boto3_session()
+    client = session.client(
+        service_name="secretsmanager", region_name=session.region_name
+    )
+    try:
+        get_secret_value_response = client.get_secret_value(SecretId=secret_id)
+    except ClientError as e:
+        sys_out_logger.error(
+            "Error while fetching secrets from secret manager : {}".format(e)
+        )
+        raise e
+    else:
+        # Depending on whether the secret is a string or binary, one of these fields will be populated.
+        if "SecretString" in get_secret_value_response:
+            secret = get_secret_value_response["SecretString"]
+        else:
+            secret = base64.b64decode(get_secret_value_response["SecretBinary"])
+    return json.loads(secret)
