@@ -1,7 +1,17 @@
+import warnings
+
 from sagemaker_studio_sparkmagic_lib.emr import utils
 
 
 def get_emr_client(boto_session):
+    """
+    https://github.com/boto/botocore/issues/2705
+
+    We are already overriding emr client with correct endpoint overrides
+    following the pattern {service}.{region}.{dnsSuffix}
+    """
+    warnings.filterwarnings("ignore", category=FutureWarning, module="botocore.client")
+
     # We need to make an EMR list instance groups call, which the sagemaker-studio-sparkmagic-lib instantiated EMR
     # client doesn't do. Also, the EMRCluster object does not provide a getter to reuse the EMR client instantiated
     # through that class. Hence we need a new client, till we can refactor both libraries. This should be fixed
